@@ -298,7 +298,8 @@ class LoadMaster(HttpClient):
                                                                vs)
             else:
                 virt_serv = self.build_virtual_service(service_data, response)
-            for server_data in service_data.get("Rs", []):
+            real_servers_x = cast_to_list(service_data.get("Rs", []))
+            for server_data in real_servers_x:
                 rs = virt_serv.build_real_server(server_data)
                 virt_serv.real_servers.append(rs)
             virtual_services.append(virt_serv)
